@@ -10,20 +10,27 @@ from .albuminfo import AlbumInfo, FolderInfo, ImportInfo, ProjectInfo
 from .debug import is_debug, set_debug
 from .exifinfo import ExifInfo
 from .exiftool import ExifTool
+from .exifwriter import ExifWriter
 from .export_db import ExportDB, ExportDBTemp
+from .exportoptions import ExportOptions, ExportResults
 from .fileutil import FileUtil, FileUtilNoOp
 from .momentinfo import MomentInfo
-from .personinfo import PersonInfo
-from .photoexporter import ExportOptions, ExportResults, PhotoExporter
+from .personinfo import FaceInfo, PersonInfo
+from .photoexporter import PhotoExporter
 from .photoinfo import PhotoInfo
-from .photosalbum import PhotosAlbum, PhotosAlbumPhotoScript
 from .photosdb import PhotosDB
 from .photosdb._photosdb_process_comments import CommentInfo, LikeInfo
+from .phototables import PhotoTables
 from .phototemplate import PhotoTemplate
 from .placeinfo import PlaceInfo
+from .platform import is_macos
 from .queryoptions import QueryOptions
 from .scoreinfo import ScoreInfo
 from .searchinfo import SearchInfo
+from .sidecars import SidecarWriter
+
+if is_macos:
+    from .photosalbum import PhotosAlbum, PhotosAlbumPhotoScript
 
 # configure logging; every module in osxphotos should use this logger
 logging.basicConfig(
@@ -40,10 +47,12 @@ __all__ = [
     "CommentInfo",
     "ExifInfo",
     "ExifTool",
+    "ExifWriter",
     "ExportDB",
     "ExportDBTemp",
     "ExportOptions",
     "ExportResults",
+    "FaceInfo",
     "FileUtil",
     "FileUtilNoOp",
     "FolderInfo",
@@ -53,6 +62,7 @@ __all__ = [
     "PersonInfo",
     "PhotoExporter",
     "PhotoInfo",
+    "PhotoTables",
     "PhotoTemplate",
     "PhotosAlbum",
     "PhotosAlbumPhotoScript",
@@ -62,6 +72,7 @@ __all__ = [
     "QueryOptions",
     "ScoreInfo",
     "SearchInfo",
+    "SidecarWriter",
     "__version__",
     "is_debug",
     "logger",
