@@ -1,12 +1,16 @@
 """Common options & parameters for osxphotos CLI commands"""
 
+
 from __future__ import annotations
 
+import contextlib
 import functools
+from textwrap import dedent
 from typing import Any, Callable
 
 import click
 
+from ..platform import is_macos
 from .common import OSXPHOTOS_HIDDEN, print_version
 from .param_types import *
 
@@ -25,6 +29,49 @@ __all__ = [
 ]
 
 
+def validate_selected(ctx, param, value):
+    """ "Validate photos are actually selected when --selected is used"""
+
+    if not value:
+        # --selected not used, just return
+        return value
+
+    # imports here to avoid conflict with linux port
+    # TODO: fix this once linux port is complete
+    import photoscript
+    from applescript import ScriptError
+
+    selection = None
+    with contextlib.suppress(ScriptError):
+        # ScriptError raised if selection made in edit mode or Smart Albums (on older versions of Photos)
+        selection = photoscript.PhotosLibrary().selection
+
+    if not selection:
+        click.echo(
+            dedent(
+                """
+                --selected option used but no photos selected in Photos.
+
+                To select photos in Photos use one of the following methods:
+    
+                - Select a single photo: Click the photo, or press the arrow keys to quickly navigate to and select the photo.
+
+                - Select a group of adjacent photos in a day: Click the first photo, then hold down the Shift key while you click the last photo.
+                You can also hold down Shift and press the arrow keys, or simply drag to enclose the photos within the selection rectangle.
+
+                - Select photos in a day that are not adjacent to each other: Hold down the Command key as you click each photo.
+
+                - Deselect specific photos: Hold down the Command key and click the photos you want to deselect.
+
+                - Deselect all photos: Click an empty space in the window (not a photo).
+            """
+            ),
+            err=True,
+        )
+        ctx.exit(1)
+    return value
+
+
 def _param_memo(f: Callable[..., Any], param: click.Parameter) -> None:
     """Add param to the list of params for a click.Command
     This is directly from the click source code and
@@ -402,22 +449,25 @@ _QUERY_PARAMETERS_DICT = {
     ),
     "--from-date": click.Option(
         ["--from-date"],
-        help="Search by item start date, e.g. 2000-01-12T12:00:00, 2001-01-12T12:00:00-07:00, or 2000-12-31 (ISO 8601 with/without timezone).",
+        metavar="DATE",
+        help="Search for items created on or after DATE, e.g. 2000-01-12T12:00:00, 2001-01-12T12:00:00-07:00, or 2000-12-31 (ISO 8601 with/without timezone).",
         type=DateTimeISO8601(),
     ),
     "--to-date": click.Option(
         ["--to-date"],
-        help="Search by item end date, e.g. 2000-01-12T12:00:00, 2001-01-12T12:00:00-07:00, or 2000-12-31 (ISO 8601 with/without timezone).",
+        metavar="DATE",
+        help="Search for items created before DATE, e.g. 2000-01-12T12:00:00, 2001-01-12T12:00:00-07:00, or 2000-12-31 (ISO 8601 with/without timezone).",
         type=DateTimeISO8601(),
     ),
     "--from-time": click.Option(
         ["--from-time"],
-        help="Search by item start time of day, e.g. 12:00, or 12:00:00.",
+        metavar="TIME",
+        help="Search for items created on or after TIME of day, e.g. 12:00, or 12:00:00.",
         type=TimeISO8601(),
     ),
     "--to-time": click.Option(
         ["--to-time"],
-        help="Search by item end time of day, e.g. 12:00 or 12:00:00.",
+        help="Search for items created before TIME of day, e.g. 12:00 or 12:00:00.",
         type=TimeISO8601(),
     ),
     "--year": click.Option(
@@ -438,7 +488,7 @@ _QUERY_PARAMETERS_DICT = {
     "--added-after": click.Option(
         ["--added-after"],
         metavar="DATE",
-        help="Search for items added to the libray after a specific date/time, "
+        help="Search for items added to the library on or after a specific date/time, "
         "e.g. --added-after e.g. 2000-01-12T12:00:00, 2001-01-12T12:00:00-07:00, or 2000-12-31 (ISO 8601 with/without timezone).",
         type=DateTimeISO8601(),
     ),
@@ -544,6 +594,46 @@ _QUERY_PARAMETERS_DICT = {
         is_flag=True,
         help="Search for photos that are not in iCloud (have not been synched)",
     ),
+    "--syndicated": click.Option(
+        ["--syndicated"],
+        is_flag=True,
+        help="Search for photos that have been shared via syndication ('Shared with You' album via Messages, etc.)",
+    ),
+    "--not-syndicated": click.Option(
+        ["--not-syndicated"],
+        is_flag=True,
+        help="Search for photos that have not been shared via syndication ('Shared with You' album via Messages, etc.)",
+    ),
+    "--saved-to-library": click.Option(
+        ["--saved-to-library"],
+        is_flag=True,
+        help="Search for syndicated photos that have saved to the library",
+    ),
+    "--not-saved-to-library": click.Option(
+        ["--not-saved-to-library"],
+        is_flag=True,
+        help="Search for syndicated photos that have not saved to the library",
+    ),
+    "--shared-moment": click.Option(
+        ["--shared-moment"],
+        is_flag=True,
+        help="Search for photos that are part of a shared moment",
+    ),
+    "--not-shared-moment": click.Option(
+        ["--not-shared-moment"],
+        is_flag=True,
+        help="Search for photos that are not part of a shared moment",
+    ),
+    "--shared-library": click.Option(
+        ["--shared-library"],
+        is_flag=True,
+        help="Search for photos that are part of a shared library",
+    ),
+    "--not-shared-library": click.Option(
+        ["--not-shared-library"],
+        is_flag=True,
+        help="Search for photos that are not part of a shared library",
+    ),
     "--regex": click.Option(
         ["--regex"],
         metavar="REGEX TEMPLATE",
@@ -557,6 +647,7 @@ _QUERY_PARAMETERS_DICT = {
         ["--selected"],
         is_flag=True,
         help="Filter for photos that are currently selected in Photos.",
+        callback=validate_selected,
     ),
     "--exif": click.Option(
         ["--exif"],
@@ -597,6 +688,9 @@ _QUERY_PARAMETERS_DICT = {
     ),
 }
 
+if not is_macos:
+    del _QUERY_PARAMETERS_DICT["--selected"]
+
 
 def QUERY_OPTIONS(
     wrapped=None, *, exclude: list[str] | None = None
