@@ -1,14 +1,18 @@
 """repl command for osxphotos CLI"""
+from __future__ import annotations
 
 import os
 import os.path
 import pathlib
+import re
+import shlex
+import subprocess
 import sys
 import time
+from functools import partial
 from typing import List
 
 import click
-import photoscript
 from rich import pretty, print
 
 import osxphotos
@@ -16,6 +20,7 @@ from osxphotos._constants import _PHOTOS_4_VERSION
 from osxphotos.cli.click_rich_echo import rich_echo_error as echo_error
 from osxphotos.photoinfo import PhotoInfo
 from osxphotos.photosdb import PhotosDB
+from osxphotos.platform import assert_macos, is_macos
 from osxphotos.pyrepl import embed_repl
 from osxphotos.queryoptions import (
     IncompatibleQueryOptions,
@@ -23,6 +28,11 @@ from osxphotos.queryoptions import (
     query_options_from_kwargs,
 )
 
+if is_macos:
+    import photoscript
+    from applescript import ScriptError
+    from osxphotos.photos_selection import PhotosSelection
+
 from .cli_params import DB_ARGUMENT, DB_OPTION, DELETED_OPTIONS, QUERY_OPTIONS
 from .common import get_photos_db
 
@@ -52,17 +62,22 @@ def repl(ctx, cli_obj, db, emacs, beta, **kwargs):
     import logging
 
     from objexplore import explore
-    from photoscript import Album, Photo, PhotosLibrary
+
+    if is_macos:
+        from photoscript import Album, Photo, PhotosLibrary
     from rich import inspect as _inspect
 
     from osxphotos import ExifTool, PhotoInfo, PhotosDB
     from osxphotos.albuminfo import AlbumInfo
+    from osxphotos.exifwriter import ExifWriter
+    from osxphotos.exportoptions import ExportOptions, ExportResults
     from osxphotos.momentinfo import MomentInfo
-    from osxphotos.photoexporter import ExportOptions, ExportResults, PhotoExporter
+    from osxphotos.photoexporter import PhotoExporter
     from osxphotos.placeinfo import PlaceInfo
     from osxphotos.queryoptions import QueryOptions
     from osxphotos.scoreinfo import ScoreInfo
     from osxphotos.searchinfo import SearchInfo
+    from osxphotos.sidecars import SidecarWriter, exiftool_json_sidecar, xmp_sidecar
 
     logger = logging.getLogger()
     logger.disabled = True
@@ -90,14 +105,12 @@ def repl(ctx, cli_obj, db, emacs, beta, **kwargs):
 
     # shortcut for helper functions
     get_photo = photosdb.get_photo
-    show = _show_photo
-    spotlight = _spotlight_photo
-    get_selected = _get_selected(photosdb)
-    try:
-        selected = get_selected()
-    except Exception:
-        # get_selected sometimes fails
-        selected = []
+    find = partial(_find_in_library, photosdb)
+
+    if is_macos:
+        show = _show_photo
+        spotlight = _spotlight_photo
+        selected = PhotosSelection(photosdb)
 
     def inspect(obj):
         """inspect object"""
@@ -106,7 +119,9 @@ def repl(ctx, cli_obj, db, emacs, beta, **kwargs):
     print(f"Found {len(photos)} photos in {tictoc:0.2f} seconds\n")
     print("The following classes have been imported from osxphotos:")
     print(
-        "- AlbumInfo, ExifTool, PhotoInfo, PhotoExporter, ExportOptions, ExportResults, PhotosDB, PlaceInfo, QueryOptions, MomentInfo, ScoreInfo, SearchInfo\n"
+        "- AlbumInfo, ExifTool, PhotoInfo, PhotoExporter, ExportOptions, ExportResults, "
+        "PhotosDB, PlaceInfo, QueryOptions, MomentInfo, ScoreInfo, SearchInfo, "
+        "SidecarWriter, ExifWriter\n"
     )
     print("The following variables are defined:")
     print(f"- photosdb: PhotosDB() instance for '{photosdb.library_path}'")
@@ -116,33 +131,36 @@ def repl(ctx, cli_obj, db, emacs, beta, **kwargs):
     print(
         f"- all_photos: list of PhotoInfo objects for all photos in photosdb, including those in the trash (len={len(all_photos)})"
     )
-    print(
-        f"- selected: list of PhotoInfo objects for any photos selected in Photos (len={len(selected)})"
-    )
+    if is_macos:
+        print(
+            f"- selected: list of PhotoInfo objects for any photos selected in Photos (len={len(selected)}); "
+            "will dynamically update as photos are selected in Photos"
+        )
     print(f"\nThe following functions may be helpful:")
     print(
-        f"- get_photo(uuid): return a PhotoInfo object for photo with uuid; e.g. get_photo('B13F4485-94E0-41CD-AF71-913095D62E31')"
+        "- get_photo(uuid): return a PhotoInfo object for photo with uuid; e.g. get_photo('B13F4485-94E0-41CD-AF71-913095D62E31')"
     )
-    print(
-        f"- get_selected(); return list of PhotoInfo objects for photos selected in Photos"
-    )
-    print(
-        f"- show(photo): open a photo object in the default viewer; e.g. show(selected[0])"
-    )
-    print(
-        f"- show(path): open a file at path in the default viewer; e.g. show('/path/to/photo.jpg')"
-    )
-    print(f"- spotlight(photo): open a photo and spotlight it in Photos")
+    if is_macos:
+        print(
+            "- show(photo): open a photo object in the default viewer; e.g. show(selected[0])"
+        )
+        print(
+            "- show(path): open a file at path in the default viewer; e.g. show('/path/to/photo.jpg')"
+        )
+        print("- spotlight(photo): open a photo and spotlight it in Photos")
     # print(
     #     f"- help(object): print help text including list of methods for object; for example, help(PhotosDB)"
     # )
     print(
-        f"- inspect(object): print information about an object; e.g. inspect(PhotoInfo)"
+        "- inspect(object): print information about an object; e.g. inspect(PhotoInfo)"
     )
     print(
-        f"- explore(object): interactively explore an object with objexplore; e.g. explore(PhotoInfo)"
+        "- explore(object): interactively explore an object with objexplore; e.g. explore(PhotoInfo)"
     )
-    print(f"- q, quit, quit(), exit, exit(): exit this interactive shell\n")
+    print(
+        "- find(text): search for files matching text in Photos library; e.g. find('B13F4485')"
+    )
+    print("- q, quit, quit(), exit, exit(): exit this interactive shell\n")
 
     embed_repl(
         globals=globals(),
@@ -187,19 +205,8 @@ def _get_all_photos(photosdb):
     return photos
 
 
-def _get_selected(photosdb):
-    """get list of PhotoInfo objects for photos selected in Photos"""
-
-    def get_selected():
-        selected = photoscript.PhotosLibrary().selection
-        if not selected:
-            return []
-        return photosdb.photos(uuid=[p.uuid for p in selected])
-
-    return get_selected
-
-
 def _spotlight_photo(photo: PhotoInfo):
+    assert_macos()
     photo_ = photoscript.Photo(photo.uuid)
     photo_.spotlight()
 
@@ -217,3 +224,20 @@ def _query_photos(photosdb: PhotosDB, query_options: QueryOptions) -> List:
         ) from e
 
     return photos
+
+
+def _find_in_library(photosdb: PhotosDB, search_str: str) -> list[str]:
+    """Find files in Photos library matching search_str using find command"""
+    # this is a quick and dirty way to find files in the Photos library
+    # e.g. those matching a UUID or a filename
+    library_path = photosdb.library_path
+    if not library_path:
+        raise ValueError("Could not find Photos library")
+
+    search_str = shlex.quote(search_str)
+    library_path = shlex.quote(library_path)
+    cmd = f"find {library_path} | grep {search_str}"
+    output = subprocess.check_output(cmd, shell=True, universal_newlines=True)
+
+    # Split the output into lines and return as a list
+    return output.strip().split("\n")
