@@ -9,13 +9,13 @@ import pathlib
 from typing import Any, Callable, Literal
 
 import click
-import photoscript
 
 from osxphotos import PhotoInfo, PhotosDB, __version__
 from osxphotos.photoinfo import PhotoInfoNone
 from osxphotos.photosalbum import PhotosAlbum
 from osxphotos.photosdb.photosdb_utils import get_db_version
 from osxphotos.phototemplate import PhotoTemplate, RenderOptions
+from osxphotos.platform import assert_macos
 from osxphotos.queryoptions import (
     IncompatibleQueryOptions,
     QueryOptions,
@@ -24,6 +24,10 @@ from osxphotos.queryoptions import (
 from osxphotos.sqlitekvstore import SQLiteKVStore
 from osxphotos.utils import pluralize
 
+assert_macos()
+
+import photoscript
+
 from .cli_params import (
     DB_OPTION,
     QUERY_OPTIONS,
@@ -167,6 +171,7 @@ def get_photo_metadata(photos: list[PhotoInfo]) -> str:
                                 photos_dict[k] = v
                             elif photos_dict[k] and v != photos_dict[k]:
                                 photos_dict[k] = f"{photos_dict[k]} {v}"
+
     # convert photos_dict to JSON string
     # wouldn't it be nice if json encoder handled datetimes...
     def default(o):
