@@ -28,7 +28,7 @@ class QueryOptions:
     """QueryOptions class for PhotosDB.query
 
     Attributes:
-        added_after: search for photos added after a given date
+        added_after: search for photos added on or after a given date
         added_before: search for photos added before a given date
         added_in_last: search for photos added in last X datetime.timedelta
         album: list of album names to search for
@@ -45,6 +45,7 @@ class QueryOptions:
         favorite: search for favorite photos
         folder: list of folder names to search for
         from_date: search for photos taken on or after this date
+        from_time: search for photos taken on or after this time of day
         function: list of query functions to evaluate
         has_comment: search for photos with comments
         has_likes: search for shared photos with likes
@@ -104,10 +105,19 @@ class QueryOptions:
         slow_mo: search for slow-mo photos
         time_lapse: search for time-lapse photos
         title: list of titles to search for
-        to_date: search for photos taken on or before this date
+        to_date: search for photos taken before this date
+        to_time: search for photos taken before this time of day
         uti: list of UTIs to search for
         uuid: list of uuids to search for
         year: search for photos taken in a given year
+        syndicated: search for photos that have been shared via syndication ("Shared with You" album via Messages, etc.)
+        not_syndicated: search for photos that have not been shared via syndication ("Shared with You" album via Messages, etc.)
+        saved_to_library: search for syndicated photos that have been saved to the Photos library
+        not_saved_to_library: search for syndicated photos that have not been saved to the Photos library
+        shared_moment: search for photos that have been shared via a shared moment
+        not_shared_moment: search for photos that have not been shared via a shared moment
+        shared_library: search for photos that are part of a shared iCloud library
+        not_shared_library: search for photos that are not part of a shared iCloud library
     """
 
     added_after: Optional[datetime.datetime] = None
@@ -192,6 +202,14 @@ class QueryOptions:
     uti: Optional[Iterable[str]] = None
     uuid: Optional[Iterable[str]] = None
     year: Optional[Iterable[int]] = None
+    syndicated: Optional[bool] = None
+    not_syndicated: Optional[bool] = None
+    saved_to_library: Optional[bool] = None
+    not_saved_to_library: Optional[bool] = None
+    shared_moment: Optional[bool] = None
+    not_shared_moment: Optional[bool] = None
+    shared_library: Optional[bool] = None
+    not_shared_library: Optional[bool] = None
 
     def asdict(self):
         return asdict(self)
@@ -261,7 +279,12 @@ def query_options_from_kwargs(**kwargs) -> QueryOptions:
         ("deleted", "not_deleted"),
         ("deleted", "deleted_only"),
         ("deleted_only", "not_deleted"),
+        ("syndicated", "not_syndicated"),
+        ("saved_to_library", "not_saved_to_library"),
+        ("shared_moment", "not_shared_moment"),
+        ("shared_library", "not_shared_library"),
     ]
+
     # TODO: add option to validate requiring at least one query arg
     for arg, not_arg in exclusive:
         if kwargs.get(arg) and kwargs.get(not_arg):
